@@ -4,10 +4,18 @@ test_that("SOA2plus_regulart", {
   expect_equal(dim(temp), c(16, 10))
   expect_false(ocheck(temp))
   set.seed(1234)
-  temp <- SOA2plus_regulart(2, 4, m=5)
+  temp <- SOA2plus_regulart(2, 4, m=5, old=TRUE)
   expect_equal(dim(temp), c(16, 5))
   expect_true(ocheck(temp))
   set.seed(1234)
+  temp <- SOA2plus_regulart(2, 4, m=7, old=TRUE)
+  expect_equal(dim(temp), c(16, 7))
+  expect_false(ocheck(temp))
+  set.seed(1234)
+  temp <- SOA2plus_regulart(2, 4, m=7)
+  expect_equal(dim(temp), c(16, 7))
+  expect_true(ocheck(temp))
+  set.seed(1234)
   temp <- SOA2plus_regulart(3, 3)
   expect_equal(dim(temp), c(27, 6))
   expect_true(ocheck(temp))
@@ -16,6 +24,23 @@ test_that("SOA2plus_regulart", {
   expect_equal(dim(temp), c(64, 8))
   expect_true(ocheck(temp))
 
+  set.seed(1234)
+  temp <- SOA2plus_regulart(2, 4, orth=FALSE)
+  expect_equal(dim(temp), c(16, 10))
+  expect_false(ocheck(temp))
+  set.seed(1234)
+  temp <- SOA2plus_regulart(2, 4, m=7, orth=FALSE)
+  expect_equal(dim(temp), c(16, 7))
+  expect_false(ocheck(temp))
+  set.seed(1234)
+  temp <- SOA2plus_regulart(3, 3, orth=FALSE)
+  expect_equal(dim(temp), c(27, 6))
+  expect_false(ocheck(temp))
+  set.seed(1234)
+  temp <- SOA2plus_regulart(4, 3, orth=FALSE)
+  expect_equal(dim(temp), c(64, 8))
+  expect_false(ocheck(temp))
+
   temp <- SOA2plus_regulart(4, 3, m=3,
                             permlist = list(
                               list(0:3,0:3,0:3),
